@@ -17,10 +17,8 @@ typedef struct siridb_pcache_s
 {
     size_t len;
     points_tp tp;
-    char * content;     /* string content */
     siridb_point_t * data;
     size_t size;   /* addition to normal points type */
-    size_t str_sz;
 } siridb_pcache_t;
 
 siridb_pcache_t * siridb_pcache_new(points_tp tp);
