@@ -32,7 +32,6 @@ typedef points_tp series_tp;
 #define SIRIDB_SERIES_INIT_REPL 4
 #define SIRIDB_SERIES_IS_SERVER_ONE 8     /* if not set its server_id 0 */
 #define SIRIDB_SERIES_IS_32BIT_TS 16    /* if not set its a 64 bit ts */
-#define SIRIDB_SERIES_IS_LOG 32         /* if not set its numeric (int/real) */
 
 /* the max length including terminator char */
 #define SIRIDB_SERIES_NAME_LEN_MAX 65535
@@ -129,6 +128,11 @@ uint8_t siridb_series_server_id_by_name(const char * name);
 int siridb_series_open_store(siridb_t * siridb);
 void siridb__series_free(siridb_series_t *__restrict series);
 void siridb__series_decref(siridb_series_t * series);
+siridb_points_t * siridb_series_get_first(
+        siridb_series_t * series, int * required_shard);
+siridb_points_t * siridb_series_get_last(
+        siridb_series_t * series, int * required_shard);
+siridb_points_t * siridb_series_get_count(siridb_series_t * series);
 /*
  * Increment the series reference counter.
  */
