@@ -5,7 +5,7 @@
  * should be used with the libcleri module.
  *
  * Source class: SiriGrammar
- * Created at: 2018-05-16 16:15:46
+ * Created at: 2018-07-05 16:20:26
  */
 #ifndef CLERI_EXPORT_SIRI_GRAMMAR_GRAMMAR_H_
 #define CLERI_EXPORT_SIRI_GRAMMAR_GRAMMAR_H_
@@ -75,7 +75,6 @@ enum cleri_grammar_ids {
     CLERI_GID_GROUP_COLUMNS,
     CLERI_GID_GROUP_MATCH,
     CLERI_GID_GROUP_NAME,
-    CLERI_GID_HELP,
     CLERI_GID_HELP_ACCESS,
     CLERI_GID_HELP_ALTER,
     CLERI_GID_HELP_ALTER_DATABASE,
@@ -112,6 +111,7 @@ enum cleri_grammar_ids {
     CLERI_GID_HELP_REVOKE,
     CLERI_GID_HELP_SELECT,
     CLERI_GID_HELP_SHOW,
+    CLERI_GID_HELP_STMT,
     CLERI_GID_HELP_TIMEIT,
     CLERI_GID_HELP_TIMEZONES,
     CLERI_GID_INT_EXPR,
@@ -161,6 +161,7 @@ enum cleri_grammar_ids {
     CLERI_GID_K_IDLE_PERCENTAGE,
     CLERI_GID_K_IDLE_TIME,
     CLERI_GID_K_IGNORE_THRESHOLD,
+    CLERI_GID_K_INF,
     CLERI_GID_K_INFO,
     CLERI_GID_K_INSERT,
     CLERI_GID_K_INTEGER,
@@ -185,6 +186,8 @@ enum cleri_grammar_ids {
     CLERI_GID_K_MIN,
     CLERI_GID_K_MODIFY,
     CLERI_GID_K_NAME,
+    CLERI_GID_K_NAN,
+    CLERI_GID_K_NINF,
     CLERI_GID_K_NOW,
     CLERI_GID_K_NUMBER,
     CLERI_GID_K_ONLINE,
