@@ -26,5 +26,5 @@
 #define F_OFFSET CLERI_GID_F_COUNT
 
 /* help statements */
-#define HELP_OFFSET CLERI_GID_HELP
+#define HELP_OFFSET CLERI_GID_HELP_ACCESS
 #define HELP_COUNT CLERI_GID_HELP_TIMEZONES + 1 - HELP_OFFSET
