@@ -12,6 +12,7 @@
 #include <cexpr/cexpr.h>
 #include <assert.h>
 #include <stddef.h>
+#include <math.h>
 #include <siri/grammar/grammar.h>
 #include <logger/logger.h>
 #include <siri/db/series.h>
@@ -150,19 +151,19 @@ int cexpr_double_cmp(
     switch (operator)
     {
     case CEXPR_EQ:
-        return a == b;
+        return isnan(a) ? isnan(b) : a == b;
     case CEXPR_NE:
-        return a != b;
+        return isnan(a) ? !isnan(b) : a != b;
     case CEXPR_GT:
         return a > b;
     case CEXPR_LT:
         return a < b;
     case CEXPR_GE:
-        return a >= b;
+        return isnan(a) ? isnan(b) : a >= b;
     case CEXPR_LE:
-        return a <= b;
+        return isnan(a) ? isnan(b) : a <= b;
     default:
-        log_critical("Got an unexpected operator (int type): %d", operator);
+        log_critical("Got an unexpected operator (double type): %d", operator);
         assert (0);
     }
     /* we should NEVER get here */
@@ -265,8 +266,8 @@ int cexpr_run(cexpr_t * cexpr, cexpr_cb_t cb, void * obj)
                     cb(obj, cexpr->via_b.cond));
     default:
         log_critical("operator must be AND or OR, got: %d", cexpr->operator);
-        assert (0);
     }
+    assert (0);
     return -1; /* this should NEVER happen */
 }
 
