@@ -349,6 +349,8 @@ static void SIRI_CFG_read_default_db_path(cfgparser_t * cfgparser)
     }
     else
     {
+        memset(siri_cfg.default_db_path, 0, SIRI_PATH_MAX);
+
         if (strlen(option->val->string) >= SIRI_PATH_MAX -2 ||
             realpath(
                 option->val->string,
@@ -359,7 +361,6 @@ static void SIRI_CFG_read_default_db_path(cfgparser_t * cfgparser)
                     "check your configuration file: %s",
                     option->val->string,
                     siri.args->config);
-            memset(siri_cfg.default_db_path, 0, SIRI_PATH_MAX);
 
             /* keep space left for a trailing slash and a terminator char */
             strncpy(siri_cfg.default_db_path,
@@ -450,8 +451,10 @@ static void SIRI_CFG_read_max_open_files(cfgparser_t * cfgparser)
         rlim.rlim_cur = min_limit;
         if (setrlimit(RLIMIT_NOFILE, &rlim))
         {
-            log_critical("Could not set the soft-limit to %d", min_limit);
-            exit(EXIT_FAILURE);
+            siri_cfg.max_open_files = (uint16_t) (rlim.rlim_cur / 2);
+            log_warning("Could not set the soft-limit to %d, "
+                    "changing max open files to: %u",
+                    min_limit, siri_cfg.max_open_files);
         }
     }
 }
