@@ -34,6 +34,7 @@
 #include <uuid/uuid.h>
 #include <xpath/xpath.h>
 #include <slist/slist.h>
+#include <timeit/timeit.h>
 
 /*
  * database.dat
@@ -54,11 +55,36 @@ static int SIRIDB_from_unpacker(
         char * err_msg);
 
 #define READ_DB_EXIT_WITH_ERROR(ERROR_MSG)  \
-    strcpy(err_msg, "error: " ERROR_MSG);   \
+    strcpy(err_msg, ERROR_MSG);             \
     siridb__free(*siridb);                  \
     *siridb = NULL;                         \
     return -1;
 
+/*
+ * Returns the up-time in seconds.
+ */
+int32_t siridb_get_uptime(siridb_t * siridb)
+{
+    return (int32_t) timeit_get(&siridb->start_time);
+}
+
+/*
+ * Returns a value in the range 0 and 100 representing how much percent sine
+ * up-time is idle time.
+ */
+int8_t siridb_get_idle_percentage(siridb_t * siridb)
+{
+    double uptime = (double) siridb_get_uptime(siridb);
+    int8_t idle = (uptime)
+            ? (int8_t) round(siridb->tasks.idle_time / uptime * 100.0f)
+            : 0;
+    /* idle time can technically be larger since we start a database before we
+     * mark the server as started.
+     */
+    return (idle > 100) ? 100 : idle;
+}
+
+
 /*
  * Check if at least database.conf and database.dat exist in the path.
  */
@@ -321,7 +347,7 @@ siridb_t * siridb_new(const char * dbpath, int lock_flags)
         }
     }
 
-    siridb->start_ts = time(NULL);
+    timeit_start(&siridb->start_time);
 
     uv_mutex_lock(&siri.siridb_mutex);
 
@@ -337,6 +363,9 @@ siridb_t * siridb_new(const char * dbpath, int lock_flags)
     /* start groups update thread */
     siridb_groups_start(siridb->groups);
 
+    /* start tasks */
+    siridb_tasks_init(&siridb->tasks);
+
     log_info("Finished loading database: '%s'", siridb->dbname);
 
     return siridb;
@@ -363,12 +392,12 @@ static int SIRIDB_from_unpacker(
     if (!qp_is_array(qp_next(unpacker, NULL)) ||
         qp_next(unpacker, &qp_schema) != QP_INT64)
     {
-        sprintf(err_msg, "error: corrupted database file.");
+        sprintf(err_msg, "Corrupted database file.");
         return -1;
     }
 
     /* check schema */
-    if (qp_schema.via.int64 == 1)
+    if (qp_schema.via.int64 == 1 || qp_schema.via.int64 == 2)
     {
         log_info(
                 "Found an old database schema (v%d), "
@@ -378,7 +407,7 @@ static int SIRIDB_from_unpacker(
     }
     else if (qp_schema.via.int64 != SIRIDB_SCHEMA)
     {
-        sprintf(err_msg, "error: unsupported schema found: %" PRId64,
+        sprintf(err_msg, "Unsupported schema found: %" PRId64,
                 qp_schema.via.int64);
         return -1;
     }
@@ -387,21 +416,20 @@ static int SIRIDB_from_unpacker(
     *siridb = SIRIDB_new();
     if (*siridb == NULL)
     {
-        sprintf(err_msg, "error: cannot create SiriDB instance");
+        sprintf(err_msg, "Cannot create SiriDB instance.");
         return -1;
     }
 
     /* set dbpath */
     if (((*siridb)->dbpath = strdup(dbpath)) == NULL)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot set dbpath.")
+        READ_DB_EXIT_WITH_ERROR("Cannot set dbpath.")
     }
 
-
     /* read uuid */
     if (qp_next(unpacker, &qp_obj) != QP_RAW || qp_obj.len != 16)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot read uuid.")
+        READ_DB_EXIT_WITH_ERROR("Cannot read uuid.")
     }
 
     /* copy uuid */
@@ -411,14 +439,14 @@ static int SIRIDB_from_unpacker(
     if (qp_next(unpacker, &qp_obj) != QP_RAW ||
             qp_obj.len >= SIRIDB_MAX_DBNAME_LEN)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot read database name.")
+        READ_DB_EXIT_WITH_ERROR("Cannot read database name.")
     }
 
     /* alloc mem for database name */
     (*siridb)->dbname = strndup((const char *) qp_obj.via.raw, qp_obj.len);
     if ((*siridb)->dbname == NULL)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot allocate database name.")
+        READ_DB_EXIT_WITH_ERROR("Cannot allocate database name.")
     }
 
     /* read time precision */
@@ -426,7 +454,7 @@ static int SIRIDB_from_unpacker(
             qp_obj.via.int64 < SIRIDB_TIME_SECONDS ||
             qp_obj.via.int64 > SIRIDB_TIME_NANOSECONDS)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot read time-precision.")
+        READ_DB_EXIT_WITH_ERROR("Cannot read time-precision.")
     }
 
     /* bind time precision to SiriDB */
@@ -434,7 +462,7 @@ static int SIRIDB_from_unpacker(
             siridb_time_new((siridb_timep_t) qp_obj.via.int64);
     if ((*siridb)->time == NULL)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot create time instance.")
+        READ_DB_EXIT_WITH_ERROR("Cannot create time instance.")
     }
 
     /* read buffer size, same buffer_size requirements are used in request.c */
@@ -442,7 +470,7 @@ static int SIRIDB_from_unpacker(
             qp_obj.via.int64 % 512 ||
             qp_obj.via.int64 < 512)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot read buffer size.")
+        READ_DB_EXIT_WITH_ERROR("Cannot read buffer size.")
     }
 
     /* bind buffer size and len to SiriDB */
@@ -452,7 +480,7 @@ static int SIRIDB_from_unpacker(
     /* read number duration  */
     if (qp_next(unpacker, &qp_obj) != QP_INT64)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot read number duration.")
+        READ_DB_EXIT_WITH_ERROR("Cannot read number duration.")
     }
 
     /* bind number duration to SiriDB */
@@ -466,7 +494,7 @@ static int SIRIDB_from_unpacker(
     /* read log duration  */
     if (qp_next(unpacker, &qp_obj) != QP_INT64)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot read log duration.")
+        READ_DB_EXIT_WITH_ERROR("Cannot read log duration.")
     }
 
     /* bind log duration to SiriDB */
@@ -483,7 +511,7 @@ static int SIRIDB_from_unpacker(
     /* read timezone */
     if (qp_next(unpacker, &qp_obj) != QP_RAW)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot read timezone.")
+        READ_DB_EXIT_WITH_ERROR("Cannot read timezone.")
     }
 
     /* bind timezone to SiriDB */
@@ -491,14 +519,14 @@ static int SIRIDB_from_unpacker(
 
     if (tzname == NULL)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot allocate timezone name.")
+        READ_DB_EXIT_WITH_ERROR("Cannot allocate timezone name.")
     }
 
     if (((*siridb)->tz = iso8601_tz(tzname)) < 0)
     {
         log_critical("Unknown timezone found: '%s'.", tzname);
         free(tzname);
-        READ_DB_EXIT_WITH_ERROR("cannot read timezone.")
+        READ_DB_EXIT_WITH_ERROR("Cannot read timezone.")
     }
     free(tzname);
 
@@ -506,7 +534,7 @@ static int SIRIDB_from_unpacker(
     if (qp_next(unpacker, &qp_obj) != QP_DOUBLE ||
             qp_obj.via.real < 0.0 || qp_obj.via.real > 1.0)
     {
-        READ_DB_EXIT_WITH_ERROR("cannot read drop threshold.")
+        READ_DB_EXIT_WITH_ERROR("Cannot read drop threshold.")
     }
     (*siridb)->drop_threshold = qp_obj.via.real;
 
@@ -520,14 +548,14 @@ static int SIRIDB_from_unpacker(
         /* read select points limit */
         if (qp_next(unpacker, &qp_obj) != QP_INT64 || qp_obj.via.int64 < 1)
         {
-            READ_DB_EXIT_WITH_ERROR("cannot read select points limit.")
+            READ_DB_EXIT_WITH_ERROR("Cannot read select points limit.")
         }
         (*siridb)->select_points_limit = qp_obj.via.int64;
 
         /* read list limit */
         if (qp_next(unpacker, &qp_obj) != QP_INT64 || qp_obj.via.int64 < 1)
         {
-            READ_DB_EXIT_WITH_ERROR("cannot read list limit.")
+            READ_DB_EXIT_WITH_ERROR("Cannot read list limit.")
         }
         (*siridb)->list_limit = qp_obj.via.int64;
     }
@@ -641,7 +669,7 @@ int siridb_save(siridb_t * siridb)
  */
 void siridb__free(siridb_t * siridb)
 {
-#ifdef DEBUG
+#if DEBUG
     log_debug("Free database: '%s'", siridb->dbname);
 #endif
 
@@ -814,7 +842,6 @@ static siridb_t * SIRIDB_new(void)
                         siridb->dbname = NULL;
                         siridb->dbpath = NULL;
                         siridb->ref = 1;
-                        siridb->active_tasks = 0;
                         siridb->insert_tasks = 0;
                         siridb->flags = 0;
                         siridb->buffer_path = NULL;
