@@ -18,6 +18,7 @@
 #include <siri/db/points.h>
 #include <siri/db/replicate.h>
 #include <siri/db/series.h>
+#include <siri/db/servers.h>
 #include <siri/err.h>
 #include <siri/net/promises.h>
 #include <siri/net/protocol.h>
@@ -25,6 +26,7 @@
 #include <siri/siri.h>
 #include <stdio.h>
 #include <string.h>
+#include <siri/db/tasks.h>
 
 #define MAX_INSERT_MSG 236
 #define INSERT_TIMEOUT 300000  // 5 minutes
@@ -92,8 +94,6 @@ static int INSERT_read_points(
         qp_obj_t * qp_obj,
         ssize_t * count);
 
-
-
 /*
  * Return an error message for an insert err.
  */
@@ -114,12 +114,15 @@ const char * siridb_insert_err_msg(siridb_insert_err_t err)
     case ERR_TIMESTAMP_OUT_OF_RANGE:
         return  "Received at least one time-stamp which is out-of-range.";
     case ERR_UNSUPPORTED_VALUE:
-        return  "Unsupported value received. (only integer and float "
+        return  "Unsupported value received. (only integer, float and string "
                 "values are supported).";
     case ERR_EXPECTING_AT_LEAST_ONE_POINT:
         return  "Expecting a series to have at least one point.";
     case ERR_EXPECTING_NAME_AND_POINTS:
         return  "Expecting a map with name and points.";
+    case ERR_INCOMPATIBLE_SERVER_VERSION:
+        return  "At least one server is incompatible for handling this "
+                "insert.";
     case ERR_MEM_ALLOC:
         return  "Critical memory allocation error";
     default:
@@ -146,7 +149,7 @@ void siridb_insert_free(siridb_insert_t * insert)
     /* free insert */
     free(insert);
 
-#ifdef DEBUG
+#if DEBUG
     log_debug("Free insert!, hooray!");
 #endif
 }
@@ -193,6 +196,7 @@ ssize_t siridb_insert_assign_pools(
     {
         rc = ERR_EXPECTING_MAP_OR_ARRAY;
     }
+
     return (siri_err) ? ERR_MEM_ALLOC : rc;
 }
 
@@ -346,7 +350,7 @@ int insert_init_backend_local(
     qp_next(&ilocal->unpacker, NULL); // map
     qp_next(&ilocal->unpacker, &ilocal->qp_series_name); // first series or end
 
-    siridb->active_tasks++;
+    siridb_tasks_inc(siridb->tasks);
     siridb->insert_tasks++;
 
     uv_async_init(siri.loop, handle, INSERT_local_task);
@@ -474,7 +478,7 @@ static void INSERT_local_free_cb(uv_async_t * handle)
 
     ilocal->promise->cb(ilocal->promise, NULL, ilocal->status);
 
-    ilocal->siridb->active_tasks--;
+    siridb_tasks_dec(ilocal->siridb->tasks);
     ilocal->siridb->insert_tasks--;
     if (ilocal->pcache != NULL)
     {
@@ -497,6 +501,8 @@ static int8_t INSERT_local_work(
     siridb_series_t * series;
     qp_obj_t qp_series_ts;
     qp_obj_t qp_series_val;
+    qp_via_t forstr;
+    qp_via_t * val;
     uint64_t * ts;
     int n = INSERT_AT_ONCE;
 
@@ -568,21 +574,52 @@ static int8_t INSERT_local_work(
                 (*pcache)->len = 0;
             }
 
+            if (series->tp == TP_STRING)
+            {
+                val = &forstr;
+                val->str = qp_is_raw(qp_series_val.tp) ?
+                        strndup(qp_series_val.via.str, qp_series_val.len) :
+                        strdup("");
+
+                if (val->str == NULL)
+                {
+                    ERR_ALLOC
+                    return INSERT_LOCAL_ERROR;
+                }
+            }
+            else
+            {
+                val = &qp_series_val.via;
+            }
+
             /* this point will always fit */
-            siridb_pcache_add_point(*pcache, ts, &qp_series_val.via);
+            siridb_pcache_add_point(*pcache, ts, val);
 
             if (tp == QP_ARRAY2) do
             {
                 qp_next(unpacker, &qp_series_ts); // ts
                 qp_next(unpacker, &qp_series_val); // val
 
+                if (series->tp == TP_STRING)
+                {
+                    val->str = qp_is_raw(qp_series_val.tp) ?
+                            strndup(qp_series_val.via.str, qp_series_val.len) :
+                            strdup("");
+
+                    if (val->str == NULL)
+                    {
+                        ERR_ALLOC
+                        return INSERT_LOCAL_ERROR;
+                    }
+                }
+
                 ts = (uint64_t *) &qp_series_ts.via.int64;
                 SERIES_UPDATE_TS(series)
 
                 if (siridb_pcache_add_point(
                         *pcache,
                         ts,
-                        &qp_series_val.via))
+                        val))
                 {
                     return INSERT_LOCAL_ERROR;  /* signal is raised */
                 }
@@ -598,8 +635,13 @@ static int8_t INSERT_local_work(
             {
                 return INSERT_LOCAL_ERROR;  /* signal is raised */
             }
-        }
 
+            if ((*pcache)->tp == TP_STRING)
+            {
+                siridb_points_free((siridb_points_t *) *pcache);
+                *pcache = NULL;
+            }
+        }
 
         if (tp == QP_ARRAY_CLOSE)
         {
@@ -628,6 +670,8 @@ static int INSERT_local_work_test(
     unsigned char * pt;
     qp_obj_t qp_series_ts;
     qp_obj_t qp_series_val;
+    qp_via_t forstr;
+    qp_via_t * val;
     int n = INSERT_AT_ONCE;
 
     /*
@@ -749,20 +793,51 @@ static int INSERT_local_work_test(
                 (*pcache)->len = 0;
             }
 
-            siridb_pcache_add_point(*pcache, ts, &qp_series_val.via);
+            if (series->tp == TP_STRING)
+            {
+                val = &forstr;
+                val->str = qp_is_raw(qp_series_val.tp) ?
+                        strndup(qp_series_val.via.str, qp_series_val.len) :
+                        strdup("");
+
+                if (val->str == NULL)
+                {
+                    ERR_ALLOC
+                    return INSERT_LOCAL_ERROR;
+                }
+            }
+            else
+            {
+                val = &qp_series_val.via;
+            }
+
+            siridb_pcache_add_point(*pcache, ts, val);
 
             if (tp == QP_ARRAY2) do
             {
                 qp_next(unpacker, &qp_series_ts); // ts
                 qp_next(unpacker, &qp_series_val); // val
 
+                if (series->tp == TP_STRING)
+                {
+                    val->str = qp_is_raw(qp_series_val.tp) ?
+                            strndup(qp_series_val.via.str, qp_series_val.len) :
+                            strdup("");
+
+                    if (val->str == NULL)
+                    {
+                        ERR_ALLOC
+                        return INSERT_LOCAL_ERROR;
+                    }
+                }
+
                 ts = (uint64_t *) &qp_series_ts.via.int64;
                 SERIES_UPDATE_TS(series)
 
                 if (siridb_pcache_add_point(
                         *pcache,
                         ts,
-                        &qp_series_val.via))
+                        val))
                 {
                     return INSERT_LOCAL_ERROR;  /* signal is raised */
                 }
@@ -778,6 +853,12 @@ static int INSERT_local_work_test(
             {
                 return INSERT_LOCAL_ERROR;  /* signal is raised */
             }
+
+            if ((*pcache)->tp == TP_STRING)
+            {
+                siridb_points_free((siridb_points_t *) *pcache);
+                *pcache = NULL;
+            }
         }
 
         if (tp == QP_ARRAY_CLOSE)
@@ -875,7 +956,7 @@ static void INSERT_local_promise_cb(
         sirinet_pkg_t * pkg,
         int status)
 {
-#ifdef DEBUG
+#if DEBUG
     assert (pkg == NULL);
 #endif
     pkg = sirinet_pkg_new(
@@ -895,7 +976,7 @@ static void INSERT_local_promise_backend_cb(
         sirinet_pkg_t * pkg,
         int status)
 {
-#ifdef DEBUG
+#if DEBUG
     assert (pkg == NULL);
 #endif
     uv_stream_t * client = (uv_stream_t *) promise->data;
@@ -977,8 +1058,9 @@ static int INSERT_init_local(
     qp_next(&ilocal->unpacker, NULL); // map
     qp_next(&ilocal->unpacker, &ilocal->qp_series_name); // first series or end
 
-    siridb->active_tasks++;
+    siridb_tasks_inc(siridb->tasks);
     siridb->insert_tasks++;
+
     uv_async_init(siri.loop, handle, INSERT_local_task);
     uv_async_send(handle);
 
@@ -1136,7 +1218,7 @@ static uint16_t INSERT_get_pool(siridb_t * siridb, qp_obj_t * qp_series_name)
              * the previous correct pool. (we can do this now
              * because we known we don't have the series)
              */
-#ifdef DEBUG
+#if DEBUG
             assert (siridb->pools->prev_lookup != NULL);
 #endif
             pool = siridb_lookup_sn_raw(
@@ -1345,7 +1427,11 @@ static int INSERT_read_points(
         switch (qp_next(unpacker, qp_obj))
         {
         case QP_RAW:
-            return ERR_UNSUPPORTED_VALUE;
+            if (siridb_servers_check_version(siridb, "2.0.27") > 0)
+            {
+                return ERR_INCOMPATIBLE_SERVER_VERSION;
+            }
+            qp_add_raw(packer, qp_obj->via.raw, qp_obj->len);
             break;
 
         case QP_INT64:
