@@ -32,7 +32,7 @@
 #include <sys/time.h>
 #include <siri/err.h>
 
-#ifdef DEBUG
+#if DEBUG
 #include <motd/motd.h>
 #endif
 
@@ -70,6 +70,7 @@ void siridb_query_run(
         float factor,
         int flags)
 {
+    siridb_t * siridb;
     uv_async_t * handle = (uv_async_t *) malloc(sizeof(uv_async_t));
     if (handle == NULL)
     {
@@ -132,7 +133,8 @@ void siridb_query_run(
     }
 
     /* increment active tasks */
-    ((sirinet_socket_t *) query->client->data)->siridb->active_tasks++;
+    siridb = ((sirinet_socket_t *) query->client->data)->siridb;
+    siridb_tasks_inc(siridb->tasks);
 
     /* send next call */
     uv_async_init(siri.loop, handle, (uv_async_cb) QUERY_parse);
@@ -143,9 +145,10 @@ void siridb_query_run(
 void siridb_query_free(uv_handle_t * handle)
 {
     siridb_query_t * query = (siridb_query_t *) handle->data;
+    siridb_t * siridb = ((sirinet_socket_t *) query->client->data)->siridb;
 
     /* decrement active tasks */
-    ((sirinet_socket_t *) query->client->data)->siridb->active_tasks--;
+    siridb_tasks_dec(siridb->tasks);
 
     /* free query */
     free(query->q);
@@ -179,7 +182,7 @@ void siridb_query_free(uv_handle_t * handle)
     /* free handle */
     free(handle);
 
-    #ifdef DEBUG
+    #if DEBUG
     log_debug("Free query!, hooray!");
     #endif
 }
@@ -191,7 +194,7 @@ void siridb_send_query_result(uv_async_t * handle)
      * clean everything without sending things in case of a client failure
      */
     siridb_query_t * query = (siridb_query_t *) handle->data;
-#ifdef DEBUG
+#if DEBUG
     if (query->packer == NULL)
     {
         sprintf(query->err_msg, "CRITICAL: We have nothing to send!");
@@ -318,7 +321,7 @@ void siridb_query_forward(
             break;
 
         case SIRIDB_QUERY_FWD_SOME_POOLS:
-#ifdef DEBUG
+#if DEBUG
 
             assert (((query_select_t *) ((siridb_query_t *)
                     handle->data)->data)->tp == QUERIES_SELECT);
@@ -404,7 +407,7 @@ void siridb_query_timeit_from_unpacker(
         siridb_query_t * query,
         qp_unpacker_t * unpacker)
 {
-#ifdef DEBUG
+#if DEBUG
     assert (query->timeit != NULL);
 #endif
 
@@ -1016,6 +1019,7 @@ static int QUERY_rebuild(
             }
             return 0;
         }
+    /* FALLTHRU */
     /* no break */
     default:
         {
