@@ -43,15 +43,6 @@
 #define BEND series->buffer->points->data[series->buffer->points->len - 1].ts
 #define DROPPED_DUMMY 1
 
-#define SERIES_GET_POINTS_CB(get_points_cb__, series__)                 \
-    get_points_cb__ = (series__->flags & SIRIDB_SERIES_IS_32BIT_TS) ?   \
-            (series__->flags & SIRIDB_SERIES_IS_LOG) ?                  \
-                    siridb_shard_get_points_log32 :                     \
-                    siridb_shard_get_points_num32 :                     \
-            (series__->flags & SIRIDB_SERIES_IS_LOG) ?                  \
-                    siridb_shard_get_points_log64 :                     \
-                    siridb_shard_get_points_num64;
-
 static int SERIES_save(siridb_t * siridb);
 static int SERIES_load(siridb_t * siridb, imap_t * dropped);
 static int SERIES_read_dropped(siridb_t * siridb, imap_t * dropped);
@@ -128,7 +119,7 @@ int siridb_series_add_point(
         uint64_t * ts,
         qp_via_t * val)
 {
-#ifdef DEBUG
+#if DEBUG
     assert (!siri_err);
     assert (series->buffer != NULL);
 #endif
@@ -337,7 +328,7 @@ siridb_series_t * siridb_series_new(
  */
 void siridb__series_free(siridb_series_t *__restrict series)
 {
-#ifdef DEBUG
+#if DEBUG
     if (siri.status == SIRI_STATUS_RUNNING || 0)
     {
         log_debug("Free series: '%s'", series->name);
@@ -376,7 +367,7 @@ void siridb__series_free(siridb_series_t *__restrict series)
  */
 int siridb_series_load(siridb_t * siridb)
 {
-#ifdef DEBUG
+#if DEBUG
     /* we must have a server because we need to know the pool id */
     assert (siridb->server != NULL);
 #endif
@@ -506,7 +497,7 @@ void siridb_series_drop_prepare(siridb_t * siridb, siridb_series_t * series)
  */
 int siridb_series_drop_commit(siridb_t * siridb, siridb_series_t * series)
 {
-#ifdef DEBUG
+#if DEBUG
     assert (series->flags & SIRIDB_SERIES_IS_DROPPED);
 #endif
 
@@ -593,12 +584,10 @@ void siridb_series_remove_shard(
         siridb_series_t *__restrict series,
         siridb_shard_t *__restrict shard)
 {
-#ifdef DEBUG
-    assert (shard->id % siridb->duration_num == series->mask);
-#endif
-
     idx_t *__restrict idx;
     uint_fast32_t i, offset;
+    uint64_t duration = (shard->tp == SIRIDB_SHARD_TP_NUMBER) ?
+                siridb->duration_num : siridb->duration_log;
 
     i = offset = 0;
 
@@ -645,7 +634,7 @@ void siridb_series_remove_shard(
                 series->idx = idx;
             }
             uint64_t start = shard->id - series->mask;
-            uint64_t end = start + siridb->duration_num;
+            uint64_t end = start + duration;
             if (series->start >= start && series->start < end)
             {
                 SERIES_update_start(series);
@@ -665,10 +654,10 @@ void siridb_series_remove_shard(
  */
 void siridb_series_update_props(siridb_t * siridb, siridb_series_t * series)
 {
-    if (series->buffer == NULL)
+    if (series->tp != TP_STRING && series->buffer == NULL)
     {
         log_error(
-            "Drop '%s' (%" PRIu32 ") since nu buffer is found for this series",
+            "Drop '%s' (%" PRIu32 ") since no buffer is found for this series",
             series->name,
             series->id);
         siridb_series_drop(siridb, series);
@@ -703,7 +692,6 @@ siridb_points_t * siridb_series_get_points(
     size_t len, size;
     uint32_t i;
     uint32_t indexes[series->idx_len];
-    siridb_shard_get_points_cb get_points_cb;
     len = i = size = 0;
 
     for (   idx = series->idx;
@@ -727,29 +715,15 @@ siridb_points_t * siridb_series_get_points(
         return NULL;  /* signal is raised */
     }
 
-    SERIES_GET_POINTS_CB(get_points_cb, series)
-
     for (i = 0; i < len; i++)
     {
         idx = series->idx + indexes[i];
-        if (idx->shard->flags & SIRIDB_SHARD_IS_COMPRESSED)
-        {
-            siridb_shard_get_points_num_compressed(
-                    points,
-                    idx,
-                    start_ts,
-                    end_ts,
-                    series->flags & SIRIDB_SERIES_HAS_OVERLAP);
-        }
-        else
-        {
-            get_points_cb(
-                    points,
-                    idx,
-                    start_ts,
-                    end_ts,
-                    series->flags & SIRIDB_SERIES_HAS_OVERLAP);
-        }
+        siridb_shard_get_points_callback(idx->shard->flags, series)(
+                points,
+                idx,
+                start_ts,
+                end_ts,
+                series->flags & SIRIDB_SERIES_HAS_OVERLAP);
         /* errors can be ignored here */
     }
 
@@ -796,7 +770,7 @@ siridb_points_t * siridb_series_get_points(
             points->data = point;
         }
     }
-#ifdef DEBUG
+#if DEBUG
     else
     {
         /* size must be equal if not smaller */
@@ -818,6 +792,161 @@ void siridb__series_decref(siridb_series_t * series)
     }
 }
 
+siridb_points_t * siridb_series_get_first(
+        siridb_series_t * series, int * required_shard)
+{
+    siridb_points_t * buf = series->buffer;
+    siridb_points_t * points;
+    uint64_t start;
+
+    if (buf != NULL &&
+        buf->len &&
+        buf->data->ts == series->start)
+    {
+        points = siridb_points_new(1, series->tp);
+        if (points == NULL)
+        {
+            return NULL;
+        }
+
+        /* string type does not have a buffer so we don't have to worry */
+        points->data->ts = buf->data->ts;
+        points->data->val = buf->data->val;
+        points->len = 1;
+        return points;
+    }
+
+    (*required_shard)++;
+
+#if DEBUG
+    /* if not in the buffer, then if must be in a shard */
+    assert (series->idx_len);
+#endif
+
+    idx_t * first = series->idx;
+
+    points = siridb_points_new(first->len, series->tp);
+    if (points == NULL)
+    {
+        return NULL;
+    }
+
+    start = series->start + 1;
+
+    siridb_shard_get_points_callback(first->shard->flags, series)(
+            points,
+            first,
+            NULL,
+            &start,
+            series->flags & SIRIDB_SERIES_HAS_OVERLAP);
+
+#if DEBUG
+    /* we must have at least one point, more points are possible when
+     * having multiple points at the same time-stamp. */
+    assert (points->len);
+#endif
+
+    while (points->len > 1)
+    {
+        --points->len;
+        if (points->tp == TP_STRING)
+        {
+            free((points->data + points->len)->val.str);
+        }
+    }
+
+    return points;
+}
+
+siridb_points_t * siridb_series_get_last(
+        siridb_series_t * series, int * required_shard)
+{
+    siridb_points_t * buf = series->buffer;
+    siridb_points_t * points;
+    siridb_point_t * point;
+
+    if (buf != NULL &&
+        buf->len &&
+        (point = buf->data + (buf->len - 1))->ts == series->end)
+    {
+        points = siridb_points_new(1, series->tp);
+        if (points == NULL)
+        {
+            return NULL;
+        }
+
+        /* string type does not have a buffer so we don't have to worry */
+        points->data->ts = point->ts;
+        points->data->val = point->val;
+        points->len = 1;
+        return points;
+    }
+
+    (*required_shard)++;
+
+
+#if DEBUG
+    /* if not in the buffer, then if must be in a shard */
+    assert (series->idx_len);
+#endif
+
+    /* if not in the buffer, then if must be in a shard */
+
+    size_t i = series->idx_len - 1;
+    idx_t * idx = series->idx + i;
+    idx_t * last = idx;
+
+    for (; i && last->shard == (--idx)->shard; --i)
+    {
+        if (idx->end_ts > last->end_ts)
+        {
+            last = idx;
+        }
+    }
+
+    points = siridb_points_new(last->len, series->tp);
+    if (points == NULL)
+    {
+        return NULL;
+    }
+
+    siridb_shard_get_points_callback(last->shard->flags, series)(
+            points,
+            last,
+            &last->end_ts,
+            NULL,
+            series->flags & SIRIDB_SERIES_HAS_OVERLAP);
+
+#if DEBUG
+    /* we must have at least one point, more points are possible when
+     * having multiple points at the same time-stamp. */
+    assert (points->len);
+#endif
+
+    while (points->len > 1)
+    {
+        --points->len;
+        if (points->tp == TP_STRING)
+        {
+            free((points->data + points->len)->val.str);
+        }
+    }
+
+    return points;
+}
+
+siridb_points_t * siridb_series_get_count(siridb_series_t * series)
+{
+    siridb_points_t * points = siridb_points_new(1, TP_INT);
+    if (points != NULL)
+    {
+        points->data->ts = series->end;
+        points->data->val.int64 = series->length;
+        points->len = 1;
+    }
+    return points;
+}
+
 /*
  * Calculate the server id.
  * Returns 0 or 1, representing a server in a pool)
@@ -847,21 +976,18 @@ int siridb_series_optimize_shard(
         siridb_series_t *__restrict series,
         siridb_shard_t *__restrict shard)
 {
-#ifdef DEBUG
-    assert (shard->id % siridb->duration_num == series->mask);
-#endif
-
     idx_t *__restrict idx;
 
     uint_fast32_t i, start, end, new_idx;
     uint64_t max_ts;
     size_t size;
     siridb_points_t *__restrict points;
-    siridb_shard_get_points_cb get_points_cb;
     int rc;
     uint16_t cinfo = 0;
+    uint64_t duration = (shard->tp == SIRIDB_SHARD_TP_NUMBER) ?
+                siridb->duration_num : siridb->duration_log;
 
-    max_ts = (shard->id + siridb->duration_num) - series->mask;
+    max_ts = (shard->id + duration) - series->mask;
 
     rc = new_idx = end = i = size = start = 0;
 
@@ -878,7 +1004,7 @@ int siridb_series_optimize_shard(
             size += idx->len;
             end++;
 
-#ifdef DEBUG
+#if DEBUG
             /*
              * we have at least 2 references to the shard so we never
              * reach 0 here.  (this ref + optimize ref)
@@ -901,18 +1027,11 @@ int siridb_series_optimize_shard(
 
     end += new_idx;
 
-    long int pos;
+    size_t pos;
     uint16_t chunk_sz;
     uint_fast32_t num_chunks, pstart, pend, diff;
-
-    if (shard->replacing->flags & SIRIDB_SHARD_IS_COMPRESSED)
-    {
-        get_points_cb = siridb_shard_get_points_num_compressed;
-    }
-    else
-    {
-        SERIES_GET_POINTS_CB(get_points_cb, series)
-    }
+    siridb_shard_get_points_cb get_points_cb = \
+            siridb_shard_get_points_callback(shard->replacing->flags, series);
 
     points = siridb_points_new(size, series->tp);
     if (points == NULL)
@@ -955,7 +1074,7 @@ int siridb_series_optimize_shard(
                 pstart,
                 pend,
                 siri.optimize->idx_fp,
-                &cinfo)) == EOF)
+                &cinfo)) == 0)
         {
             log_critical(
                     "Cannot write points to shard id '%" PRIu64 "'",
@@ -976,7 +1095,7 @@ int siridb_series_optimize_shard(
             }
             while (idx->shard == shard);
 
-#ifdef DEBUG
+#if DEBUG
             assert (idx->shard == shard->replacing);
 #endif
 
@@ -1041,7 +1160,7 @@ int siridb_series_optimize_shard(
             series->idx = idx;
         }
     }
-#ifdef DEBUG
+#if DEBUG
     else
     {
         /* start must be equal to end if not smaller */
@@ -1130,7 +1249,7 @@ static void SERIES_idx_sort(
  */
 static void SERIES_update_overlap(siridb_series_t *__restrict series)
 {
-#ifdef DEBUG
+#if DEBUG
     assert (series->flags & SIRIDB_SERIES_HAS_OVERLAP);
 #endif
     for (uint_fast32_t i = 1; i < series->idx_len; i++)
@@ -1192,16 +1311,16 @@ static siridb_series_t * SERIES_new(
                 n += *name;
             }
 
-            series->mask =
-                    (uint16_t) (n / 11) % ((tp == TP_STRING) ?
-                    siridb->shard_mask_log : siridb->shard_mask_num);
+            series->mask = (tp == TP_STRING) ?
+                    (uint16_t) ((n / 11) % siridb->shard_mask_log) + 600 :
+                    (uint16_t) ((n / 11) % siridb->shard_mask_num);
 
             if ((uint8_t) ((n / 11) % 2))
             {
                 series->flags |= SIRIDB_SERIES_IS_SERVER_ONE;
             }
 
-#ifdef DEBUG
+#if DEBUG
             /* make sure these two are exactly the same */
             assert (siridb_series_server_id(series) ==
                     siridb_series_server_id_by_name(series->name));
@@ -1211,13 +1330,7 @@ static siridb_series_t * SERIES_new(
             {
                 series->flags |= SIRIDB_SERIES_IS_32BIT_TS;
             }
-
-            if (tp == TP_STRING)
-            {
-                series->flags |= SIRIDB_SERIES_IS_LOG;
-            }
         }
-
     }
     return series;
 }
@@ -1555,7 +1668,7 @@ static void SERIES_update_start(siridb_series_t *__restrict series)
 {
     series->start = series->idx_len ? series->idx->start_ts : UINT64_MAX;
 
-    if (series->buffer->len)
+    if (series->buffer && series->buffer->len)
     {
         siridb_point_t * point = series->buffer->data;
         if (point->ts < series->start)
@@ -1595,7 +1708,7 @@ static void SERIES_update_end(siridb_series_t *__restrict series)
         series->end = 0;
     }
 
-    if (series->buffer->len)
+    if (series->buffer && series->buffer->len)
     {
         siridb_point_t * point = series->buffer->data +
                 series->buffer->len - 1;
