@@ -5,7 +5,7 @@
  * should be used with the libcleri module.
  *
  * Source class: SiriGrammar
- * Created at: 2018-05-16 16:15:46
+ * Created at: 2018-07-05 16:20:26
  */
 
 #include "siri/grammar/grammar.h"
@@ -79,6 +79,7 @@ cleri_grammar_t * compile_grammar(void)
     );
     cleri_t * k_idle_percentage = cleri_keyword(CLERI_GID_K_IDLE_PERCENTAGE, "idle_percentage", CLERI_CASE_SENSITIVE);
     cleri_t * k_idle_time = cleri_keyword(CLERI_GID_K_IDLE_TIME, "idle_time", CLERI_CASE_SENSITIVE);
+    cleri_t * k_inf = cleri_keyword(CLERI_GID_K_INF, "inf", CLERI_CASE_SENSITIVE);
     cleri_t * k_info = cleri_keyword(CLERI_GID_K_INFO, "info", CLERI_CASE_SENSITIVE);
     cleri_t * k_ignore_threshold = cleri_keyword(CLERI_GID_K_IGNORE_THRESHOLD, "ignore_threshold", CLERI_CASE_SENSITIVE);
     cleri_t * k_insert = cleri_keyword(CLERI_GID_K_INSERT, "insert", CLERI_CASE_SENSITIVE);
@@ -109,7 +110,14 @@ cleri_grammar_t * compile_grammar(void)
     cleri_t * k_merge = cleri_keyword(CLERI_GID_K_MERGE, "merge", CLERI_CASE_SENSITIVE);
     cleri_t * k_min = cleri_keyword(CLERI_GID_K_MIN, "min", CLERI_CASE_SENSITIVE);
     cleri_t * k_modify = cleri_keyword(CLERI_GID_K_MODIFY, "modify", CLERI_CASE_SENSITIVE);
+    cleri_t * k_nan = cleri_keyword(CLERI_GID_K_NAN, "nan", CLERI_CASE_SENSITIVE);
     cleri_t * k_name = cleri_keyword(CLERI_GID_K_NAME, "name", CLERI_CASE_SENSITIVE);
+    cleri_t * k_ninf = cleri_sequence(
+        CLERI_GID_K_NINF,
+        2,
+        cleri_token(CLERI_NONE, "-"),
+        k_inf
+    );
     cleri_t * k_now = cleri_keyword(CLERI_GID_K_NOW, "now", CLERI_CASE_SENSITIVE);
     cleri_t * k_number = cleri_keyword(CLERI_GID_K_NUMBER, "number", CLERI_CASE_SENSITIVE);
     cleri_t * k_online = cleri_keyword(CLERI_GID_K_ONLINE, "online", CLERI_CASE_SENSITIVE);
@@ -946,10 +954,14 @@ cleri_grammar_t * compile_grammar(void)
         cleri_choice(
             CLERI_NONE,
             CLERI_MOST_GREEDY,
-            3,
+            7,
             string,
             r_integer,
-            r_float
+            r_float,
+            r_regex,
+            k_nan,
+            k_inf,
+            k_ninf
         ),
         cleri_token(CLERI_NONE, ")")
     );
@@ -1510,6 +1522,29 @@ cleri_grammar_t * compile_grammar(void)
         ), cleri_token(CLERI_NONE, ","), 0, 0, 0)
     );
     cleri_t * timeit_stmt = cleri_dup(CLERI_GID_TIMEIT_STMT, k_timeit);
+    cleri_t * help_stmt = cleri_ref();
+    cleri_t * START = cleri_sequence(
+        CLERI_GID_START,
+        3,
+        cleri_optional(CLERI_NONE, timeit_stmt),
+        cleri_optional(CLERI_NONE, cleri_choice(
+            CLERI_NONE,
+            CLERI_FIRST_MATCH,
+            11,
+            select_stmt,
+            list_stmt,
+            count_stmt,
+            alter_stmt,
+            create_stmt,
+            drop_stmt,
+            grant_stmt,
+            revoke_stmt,
+            show_stmt,
+            calc_stmt,
+            help_stmt
+        )),
+        cleri_optional(CLERI_NONE, r_comment)
+    );
     cleri_t * help_access = cleri_keyword(CLERI_GID_HELP_ACCESS, "access", CLERI_CASE_SENSITIVE);
     cleri_t * help_alter_database = cleri_keyword(CLERI_GID_HELP_ALTER_DATABASE, "database", CLERI_CASE_SENSITIVE);
     cleri_t * help_alter_group = cleri_keyword(CLERI_GID_HELP_ALTER_GROUP, "group", CLERI_CASE_SENSITIVE);
@@ -1617,8 +1652,8 @@ cleri_grammar_t * compile_grammar(void)
     cleri_t * help_show = cleri_keyword(CLERI_GID_HELP_SHOW, "show", CLERI_CASE_SENSITIVE);
     cleri_t * help_timeit = cleri_keyword(CLERI_GID_HELP_TIMEIT, "timeit", CLERI_CASE_SENSITIVE);
     cleri_t * help_timezones = cleri_keyword(CLERI_GID_HELP_TIMEZONES, "timezones", CLERI_CASE_SENSITIVE);
-    cleri_t * help = cleri_sequence(
-        CLERI_GID_HELP,
+    cleri_ref_set(help_stmt, cleri_sequence(
+        CLERI_GID_HELP_STMT,
         2,
         k_help,
         cleri_optional(CLERI_NONE, cleri_choice(
@@ -1640,29 +1675,7 @@ cleri_grammar_t * compile_grammar(void)
             help_timeit,
             help_timezones
         ))
-    );
-    cleri_t * START = cleri_sequence(
-        CLERI_GID_START,
-        3,
-        cleri_optional(CLERI_NONE, timeit_stmt),
-        cleri_optional(CLERI_NONE, cleri_choice(
-            CLERI_NONE,
-            CLERI_FIRST_MATCH,
-            11,
-            select_stmt,
-            list_stmt,
-            count_stmt,
-            alter_stmt,
-            create_stmt,
-            drop_stmt,
-            grant_stmt,
-            revoke_stmt,
-            show_stmt,
-            calc_stmt,
-            help
-        )),
-        cleri_optional(CLERI_NONE, r_comment)
-    );
+    ));
 
     cleri_grammar_t * grammar = cleri_grammar(START, "^[a-z_]+");
 
