@@ -67,7 +67,7 @@ sirinet_pkg_t * sirinet_pkg_new(
  */
 qp_packer_t * sirinet_packer_new(size_t alloc_size)
 {
-#ifdef DEBUG
+#if DEBUG
     assert (alloc_size >= sizeof(sirinet_pkg_t));
 #endif
 
@@ -119,7 +119,7 @@ sirinet_pkg_t * sirinet_pkg_err(
         uint8_t tp,
         const char * msg)
 {
-#ifdef DEBUG
+#if DEBUG
     assert (msg != NULL);
 #endif
 
