@@ -34,6 +34,7 @@
 #include <siri/version.h>
 #include <siri/db/lookup.h>
 #include <strextra/strextra.h>
+#include <math.h>
 
 #define TEST_OK 1
 #define TEST_FAILED -1
@@ -710,7 +711,7 @@ static int test_aggr_min(void)
 
 static int test_aggr_pvariance(void)
 {
-    test_start("Testing pvariance");
+    test_start("Testing aggregation pvariance");
 
     siridb_aggr_t aggr;
     siridb_points_t * result;
@@ -768,7 +769,7 @@ static int test_aggr_sum(void)
 
 static int test_aggr_variance(void)
 {
-    test_start("Testing variance");
+    test_start("Testing aggregation variance");
 
     siridb_aggr_t aggr;
     siridb_points_t * result;
@@ -795,6 +796,93 @@ static int test_aggr_variance(void)
     return test_end(TEST_OK);
 }
 
+static int test_aggr_stddev(void)
+{
+    test_start("Testing aggregation standard deviation");
+
+    siridb_aggr_t aggr;
+    siridb_points_t * result;
+    char err_msg[SIRIDB_MAX_SIZE_ERR_MSG];
+    siridb_points_t * points = prepare_points();
+
+    aggr.gid = CLERI_GID_F_STDDEV;
+    aggr.group_by = 6;
+    aggr.limit = 0;
+    aggr.offset = 0;
+
+    result = siridb_aggregate_run(points, &aggr, err_msg);
+
+    assert (result != NULL);
+    assert (result->len == 4);
+    assert (result->tp == TP_DOUBLE);
+    assert (result->data->ts == 6 && result->data->val.real == sqrt(2.0));
+    assert ((result->data + 1)->ts == 12 &&
+            (result->data + 1)->val.real == 2.0);
+
+    siridb_points_free(result);
+    siridb_points_free(points);
+
+    return test_end(TEST_OK);
+}
+
+static int test_aggr_first(void)
+{
+    test_start("Testing aggregation first");
+
+    siridb_aggr_t aggr;
+    siridb_points_t * result;
+    char err_msg[SIRIDB_MAX_SIZE_ERR_MSG];
+    siridb_points_t * points = prepare_points();
+
+    aggr.gid = CLERI_GID_F_FIRST;
+    aggr.group_by = 5;
+    aggr.limit = 0;
+    aggr.offset = 0;
+
+    result = siridb_aggregate_run(points, &aggr, err_msg);
+
+    assert (result != NULL);
+    assert (result->len == 5);
+    assert (result->tp == TP_INT);
+    assert (result->data->ts == 5 && result->data->val.int64 == 1);
+    assert ((result->data + 2)->ts == 15 &&
+            (result->data + 2)->val.int64 == 4);
+
+    siridb_points_free(result);
+    siridb_points_free(points);
+
+    return test_end(TEST_OK);
+}
+
+static int test_aggr_last(void)
+{
+    test_start("Testing aggregation last");
+
+    siridb_aggr_t aggr;
+    siridb_points_t * result;
+    char err_msg[SIRIDB_MAX_SIZE_ERR_MSG];
+    siridb_points_t * points = prepare_points();
+
+    aggr.gid = CLERI_GID_F_LAST;
+    aggr.group_by = 5;
+    aggr.limit = 0;
+    aggr.offset = 0;
+
+    result = siridb_aggregate_run(points, &aggr, err_msg);
+
+    assert (result != NULL);
+    assert (result->len == 5);
+    assert (result->tp == TP_INT);
+    assert (result->data->ts == 5 && result->data->val.int64 == 1);
+    assert ((result->data + 2)->ts == 15 &&
+            (result->data + 2)->val.int64 == 5);
+
+    siridb_points_free(result);
+    siridb_points_free(points);
+
+    return test_end(TEST_OK);
+}
+
 static int test_iso8601(void)
 {
     test_start("Testing iso8601");
@@ -929,7 +1017,7 @@ int test_strx_to_double(void)
 
 int run_tests(void)
 {
-    timeit_t start;
+    struct timespec start;
     timeit_start(&start);
     int rc = 0;
     rc += test_qpack();
@@ -952,6 +1040,9 @@ int run_tests(void)
     rc += test_aggr_pvariance();
     rc += test_aggr_sum();
     rc += test_aggr_variance();
+    rc += test_aggr_stddev();
+    rc += test_aggr_first();
+    rc += test_aggr_last();
     rc += test_iso8601();
     rc += test_expr();
     rc += test_access();
@@ -959,7 +1050,7 @@ int run_tests(void)
     rc += test_strx_to_double();
 
     printf("\nSuccessfully performed %d tests in %.3f milliseconds!\n\n",
-            rc, timeit_stop(&start));
+            rc, timeit_get(&start) * 1000);
 
     return 0;
 }
