@@ -2,6 +2,7 @@ import unittest
 import time
 import asyncio
 import random
+import math
 import collections
 from .siridb import SiriDB
 from .server import Server
@@ -92,12 +93,12 @@ class TestBase(unittest.TestCase):
                     .format(len(s.points), length, s.name)
 
         n = min(len(series), 10)
-        l = list(d.keys())
-        random.shuffle(l)
+        li = list(d.keys())
+        random.shuffle(li)
         for i in range(n):
-            result = await client.query('select * from "{}"'.format(l[i]))
-            points = result[l[i]]
-            expected = sorted(d[l[i]])
+            result = await client.query('select * from "{}"'.format(li[i]))
+            points = result[li[i]]
+            expected = sorted(d[li[i]])
             assert len(points) == len(expected), \
                 'incorrect number of points: {}, expected: {}'.format(
                     len(points), len(expected))
@@ -115,13 +116,15 @@ class TestBase(unittest.TestCase):
                     assert isinstance(point, list) and len(point) == 2, \
                         'Expecting a point to be a list of 2 items'
                     super().assertEqual(a[series][i][0], point[0])
-                    super().assertAlmostEqual(
-                        a[series][i][1],
-                        point[1],
-                        *args,
-                        **kwargs)
+                    if math.isnan(a[series][i][1]):
+                        assert math.isnan(point[1]), \
+                            'Expecting point `{}` to be `nan`, got: `{}`' \
+                            .format(i, point[1])
+                    else:
+                        super().assertAlmostEqual(
+                            a[series][i][1],
+                            point[1],
+                            *args,
+                            **kwargs)
         else:
             super().assertAlmostEqual(a, b, *args, **kwargs)
-
-
-
